<template>
  当前患者: {{patient.patId}} {{isStringEmpty(patient.patName)?'无':patient.patName}}
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="设备编号" prop="devId">
        <el-input v-model="formData.devId" placeholder="请输入设备编号" />
      </el-form-item>
      <el-form-item label="装机时间" prop="rentTime">
        <el-date-picker
          v-model="formData.rentTime"
          type="date"
          value-format="x"
          placeholder="选择装机时间"
        />
      </el-form-item>
      <el-form-item label="拆机时间" prop="returnTime">
        <el-date-picker
          v-model="formData.returnTime"
          type="date"
          value-format="x"
          placeholder="选择拆机时间"
        />
      </el-form-item>
      <el-form-item label="干扰数" prop="interference">
        <el-input v-model="formData.interference" placeholder="请输入干扰数" />
      </el-form-item>
      <el-form-item label="基线粗" prop="baseline">
        <el-input v-model="formData.baseline" placeholder="请输入基线粗" />
      </el-form-item>
      <el-form-item label="脱离" prop="detachment">
        <el-input v-model="formData.detachment" placeholder="请输入脱离" />
      </el-form-item>
      <el-form-item label="备注" prop="remark">
        <el-input v-model="formData.remark" placeholder="请输入备注" />
      </el-form-item>
    </el-form>
    <el-button @click="submitForm" type="primary" :disabled="formLoading">装机</el-button>
    <el-button @click="dialogVisible = false">取 消</el-button>
</template>

<script setup lang="ts">
import {defineComponent, PropType} from "vue";
import { DevRentApi, DevRentVO } from '@/api/ecg/devrent'
import {QueueVO} from "@/api/ecg/queue";
import {isStringEmpty} from "@/utils/stringUtil";

/** 装机拆机 表单 */
defineComponent({ name: 'DevInstallPanel' })

const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示

const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('create') // 表单的类型：create - 新增；update - 修改

const patient = ref<QueueVO>({
  patId: '',
  patName: ''
})

const formData = ref({
  id: undefined,
  devId: undefined,
  patId: patient.value.patId,
  patName: patient.value.patName,
  rentTime: new Date().getTime(),
  returnTime: undefined,
  interference: undefined,
  baseline: undefined,
  detachment: undefined,
  remark: undefined
})
const formRules = reactive({
  devId: [{ required: true, message: '设备编号不能为空', trigger: 'blur' }],
  patId: [{ required: true, message: '目前没有患者', trigger: 'blur' }],
  patName: [{ required: true, message: '目前没有患者', trigger: 'blur' }]
})
const formRef = ref() // 表单 Ref

/** 提交表单 */
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as DevRentVO
    data.patId = patient.value.patId
    data.patName = patient.value.patName
    if (formData.value.id === null || formData.value.id === undefined) {
      const result = await DevRentApi.createDevRent(data)
      formData.value.id = result
      message.success(t('common.createSuccess'))
    } else {
      await DevRentApi.updateDevRent(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    devId: undefined,
    patId: patient.value.patId,
    patName: patient.value.patName,
    rentTime: new Date().getTime(),
    returnTime: undefined,
    interference: undefined,
    baseline: undefined,
    detachment: undefined,
    remark: undefined
  }
  formRef.value?.resetFields()
}

const setPatient = (queueVO: QueueVO) => {
  patient.value = queueVO
  formData.value.id = undefined
}
defineExpose({ setPatient }) // 提供 setPatient 方法，用于设置患者

</script>

